@@ -1,6 +1,7 @@
 """
 Contains common trace extractors and delegators
 """
+from flask import request, g
 
 
 def gcloud_trace_extractor(project_id):
@@ -10,7 +11,7 @@ def gcloud_trace_extractor(project_id):
         project_id {str} -- project id
     """
 
-    def extractor(request):
+    def extractor():
         trace = request.headers.get("X-Cloud-Trace-Context")
         if not trace:
             return None
@@ -26,8 +27,11 @@ def gcloud_trace_delegator():
         trace {str} -- trace
     """
 
-    def delegator(trace):
-        header = trace.split("/")[-1]
-        return "X-Cloud-Trace-Context", header
+    def delegator():
+        if g.trace:
+            header = g.trace.split("/")[-1]
+            return "X-Cloud-Trace-Context", header
+        else:
+            return "X-Cloud-Trace-Context", ""
 
     return delegator
